# Generated by roxygen2: do not edit by hand

export(janusplot)
export(janusplot_data)
export(janusplot_shape_cutoffs)
export(janusplot_shape_hierarchy)
export(janusplot_shape_metrics)
export(janusplot_shape_sensitivity)
export(janusplot_shape_sensitivity_plot)
export(janusplot_shape_sensitivity_shapes)
export(janusplot_shape_sensitivity_summary)
importFrom(rlang,.data)
importFrom(rlang,arg_match)
importFrom(rlang,check_installed)
importFrom(rlang,is_installed)
importFrom(stats,as.dist)
importFrom(stats,as.formula)
importFrom(stats,complete.cases)
importFrom(stats,cor)
importFrom(stats,hclust)
importFrom(stats,predict)
importFrom(stats,quantile)
importFrom(stats,sd)
